==> qtharmony-0.2.1-py3-none-any.whl: qtharmony/widgets/basic/groups.py <==
from typing import Optional, TYPE_CHECKING
from PySide6.QtWidgets import (
    QGroupBox, QButtonGroup,
    QHBoxLayout, QVBoxLayout, QLayout
)

from qtharmony.src.core import StyleSheetLoader
from qtharmony.src.core.theme import ThemeManager 

if TYPE_CHECKING:
    from PySide6.QtWidgets import QWidget


def copy_method(source_class, method_name):
    
    def decorator(target_class):
    
        def wrapper(self, *args, **kwargs):
            source_method = getattr(source_class, method_name)
            return source_method(self, *args, **kwargs)
    
        setattr(target_class, method_name, wrapper)
        return target_class
    
    return decorator


class GroupBox(QGroupBox):
    """
    Custom QGroupBox widget for grouping widgets.

    Methods:
    - __init__(title: Optional[str] = None, *, stylesheet: Optional[str] = None, parent: Optional["QWidget"] = None): None
              - Initializes the GroupBox widget with optional title and stylesheet.
    """

    def __init__(
            self,
            title: Optional[str] = None,
            size: tuple[int, int] = (400, 200),
            orientation: str = "vertical",
            *,
            stylesheet: Optional[str] = None,
            parent: Optional["QWidget"] = None
    ) -> None:
        """
        Initializes the GroupBox widget with optional title and stylesheet.

        Args:
            title (Optional[str], optional): The title of the group box. Defaults to None.
            stylesheet (Optional[str], optional): Custom stylesheet for the group box widget. Defaults to None.
            parent (Optional["QWidget"], optional): Parent widget of the group box. Defaults to None.
        """

        super().__init__(parent)
        ThemeManager.add_widgets(self)

        self.setObjectName("group-box")
        self.stylesheet = StyleSheetLoader.load_stylesheet(
            __file__, "styles/group_box.css", 
            name="GroupBox", obj_name="QGroupBox#group-box",
            stylesheet=stylesheet
        )

        if title is not None: self.setTitle(title)
        self.setFixedSize(*size)

        if orientation == "vertical": self.mainLayout = QVBoxLayout()
        elif orientation == "horizontal": self.mainLayout = QHBoxLayout()
        else: raise ValueError("Invalid orientation. should be use 'vertical' or 'horizontal'.")

        self.setLayout(self.mainLayout)
    
    def addWidget(self, *args, **kwargs) -> None:
        self.mainLayout.addWidget(*args, **kwargs)
    
    def addLayout(self, *args, **kwargs) -> None:
        self.mainLayout.addLayout(*args, **kwargs)
    
    def addItem(self, *args, **kwargs) -> None:
        self.mainLayout.addItem(*args, **kwargs)

==> qtharmony-0.2.5-py3-none-any.whl: qtharmony/widgets/basic/groups.py <==
from typing import Optional, TYPE_CHECKING
from PySide6.QtWidgets import (
    QGroupBox, QButtonGroup,
    QHBoxLayout, QVBoxLayout, QLayout
)

from qtharmony.src.core import StyleSheetLoader
from qtharmony.src.core.theme import ThemeManager 

if TYPE_CHECKING:
    from PySide6.QtWidgets import QWidget


def copy_method(source_class, method_name):
    
    def decorator(target_class):
    
        def wrapper(self, *args, **kwargs):
            source_method = getattr(source_class, method_name)
            return source_method(self, *args, **kwargs)
    
        setattr(target_class, method_name, wrapper)
        return target_class
    
    return decorator


class GroupBox(QGroupBox):
    """
    Custom QGroupBox widget for grouping widgets.

    Methods:
    - __init__(title: Optional[str] = None, *, stylesheet: Optional[str] = None, parent: Optional["QWidget"] = None): None
              - Initializes the GroupBox widget with optional title and stylesheet.
    """

    def __init__(
            self,
            title: Optional[str] = None,
            size: Optional[tuple[int, int]] = None,
            orientation: str = "vertical",
            *,
            stylesheet: Optional[str] = None,
            parent: Optional["QWidget"] = None
    ) -> None:
        """
        Initializes the GroupBox widget with optional title and stylesheet.

        Args:
            title (Optional[str], optional): The title of the group box. Defaults to None.
            stylesheet (Optional[str], optional): Custom stylesheet for the group box widget. Defaults to None.
            parent (Optional["QWidget"], optional): Parent widget of the group box. Defaults to None.
        """

        super().__init__(parent)
        ThemeManager.add_widgets(self)

        self.setObjectName("group-box")
        self.stylesheet = StyleSheetLoader.load_stylesheet(
            __file__, "styles/group_box.css", 
            name="GroupBox", obj_name="QGroupBox#group-box",
            stylesheet=stylesheet
        )

        if title is not None: self.setTitle(title)
        if size is not None: self.setFixedSize(*size)

        if orientation == "vertical": self.mainLayout = QVBoxLayout()
        elif orientation == "horizontal": self.mainLayout = QHBoxLayout()
        else: raise ValueError("Invalid orientation. should be use 'vertical' or 'horizontal'.")

        self.setLayout(self.mainLayout)
    
    def addWidget(self, *args, **kwargs) -> None:
        self.mainLayout.addWidget(*args, **kwargs)
    
    def addLayout(self, *args, **kwargs) -> None:
        self.mainLayout.addLayout(*args, **kwargs)
    
    def addItem(self, *args, **kwargs) -> None:
        self.mainLayout.addItem(*args, **kwargs)
